"""Top-level package for Domain Utils."""

__author__ = """Sarah Bird"""
__email__ = 'sbird@mozilla.com'
__version__ = '0.3.0'

from .domain_utils import *  # noqa
